"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RepositoryClone = void 0;
const template_1 = require("../../repositorys/template");
const path_1 = require("path");
const fs_1 = require("fs");
const inquirer = require("inquirer");
const progress_1 = require("../../utils/progress");
const download = require("download-git-repo");
class RepositoryClone {
    constructor(options) {
        const newLocal = this;
        newLocal.actionHandler(options);
    }
    actionHandler(options) {
        this.handleInputInfo();
    }
    handleInputInfo() {
        return __awaiter(this, void 0, void 0, function* () {
            const answers = yield inquirer.prompt([
                {
                    type: "list",
                    name: "repository",
                    message: "选择要克隆的模版",
                    choices: template_1.RepositoryTemplates.map((v) => (Object.assign(Object.assign({}, v), { value: v }))),
                },
                {
                    type: "input",
                    name: "name",
                    message: "输入程序名称：",
                    validate: function (input) {
                        const done = this.async();
                        setTimeout(function () {
                            if (fs_1.existsSync(path_1.resolve("./", input))) {
                                done(`文件名: ${input} 在当前目录已存在，请重新输入`);
                                return;
                            }
                            done(null, true);
                        }, 100);
                    },
                },
            ]);
            this.handleCloneRepository(answers);
        });
    }
    handleCloneRepository(answers) {
        return __awaiter(this, void 0, void 0, function* () {
            this.downloadRespository(answers.repository, answers.name);
        });
    }
    downloadRespository(reposConf, newName) {
        return __awaiter(this, void 0, void 0, function* () {
            const downloadPath = path_1.resolve("./", newName);
            const loading = new progress_1.Loading();
            loading.start();
            download(`direct:${reposConf.address}#${reposConf.branch}`, downloadPath, { clone: true }, function (err) {
                if (err) {
                    throw new Error(err);
                }
                loading.stop();
            });
        });
    }
}
exports.RepositoryClone = RepositoryClone;
