import chalk = require("chalk");
import { Repository, RepositoryTemplates } from "../../repositorys/template";
import { resolve } from "path";
import { createWriteStream } from "fs";
import { Socket } from "net";
import { existsSync } from "fs";
const inquirer = require("inquirer");
import { Loading } from "../../utils/progress";
const download = require("download-git-repo");

export class RepositoryClone {
    constructor(options: any) {
        const newLocal = this;
        newLocal.actionHandler(options);
    }

    actionHandler(options: any) {
        this.handleInputInfo();
    }

    async handleInputInfo() {
        const answers: any = await inquirer.prompt([
            {
                type: "list",
                name: "repository",
                message: "选择要克隆的模版",
                choices: RepositoryTemplates.map((v) => ({ ...v, value: v })),
            },
            {
                type: "input",
                name: "name",
                message: "输入程序名称：",
                validate: function (input: string) {
                    const done = this.async();

                    setTimeout(function () {
                        // 判断目标目录是否冲突
                        if (existsSync(resolve("./", input))) {
                            done(`文件名: ${input} 在当前目录已存在，请重新输入`);
                            return;
                        }
                        done(null, true);
                    }, 100);
                },
            },
        ]);

        this.handleCloneRepository(answers);
    }

    async handleCloneRepository(answers: any) {
        this.downloadRespository(answers.repository as Repository, answers.name);
    }

    async downloadRespository(reposConf: Repository, newName: string) {
        const downloadPath = resolve("./", newName);
        const loading = new Loading();

        loading.start();
        download(`direct:${reposConf.address}#${reposConf.branch}`, downloadPath, { clone: true }, function (err: any) {
            if (err) {
                throw new Error(err);
            }
            loading.stop();
        });
    }
}
