import { Command, program } from "commander";
import * as chalk from "chalk";

import { RepositoryList } from "./list";
import { RepositoryClone } from "./clone";

export interface CommaderFunc {
    init(program: Command): void;
    handleAction(cmd: string, options: Record<string, any>): void;
}

export class Templatemanager implements CommaderFunc {
    private program: Command;

    constructor(program: Command) {
        this.program = program;
        this.init(program);
    }

    init(program: Command) {
        program
            .command("temp")
            .alias("t")
            .description("模版管理")
            .argument("<list | new>", "列出所有模版列表")
            .action(this.handleAction);
    }

    handleAction(cmd: string, options: Record<string, any>): void {
        switch (cmd) {
            case "list":
                new RepositoryList(options);
                break;
            case "new":
                new RepositoryClone(options);
                break;
            default:
                console.log(chalk.red(`❎ 没有这个命令`), chalk.bgBlue(cmd));
                break;
        }
    }
}

export const initCommander = (program: Command) => {
    new Templatemanager(program);
};
